@@ -214,7 +214,7 @@ fn loop_inner(input: LoopParams, span: Span) -> Result<TokenStream2, Box<dyn Err
         Some(f) => f,
         None => {
             parse2::<Path>(quote! {
-                 sing::callobj_to_string
+                 sing_rs::callobj_to_string
             })?
         }
     };
@@ -224,7 +224,7 @@ fn loop_inner(input: LoopParams, span: Span) -> Result<TokenStream2, Box<dyn Err
         Some(f) => f,
         None => {
             parse2::<Path>(quote! {
-                 sing::callobj_from_string
+                 sing_rs::callobj_from_string
             })?
         }
     };
@@ -282,7 +282,7 @@ fn loop_inner(input: LoopParams, span: Span) -> Result<TokenStream2, Box<dyn Err
     let message_type = match message_type {
         Some(m) => m,
         None => parse2::<Path>(quote! {
-				sing::CallObj
+				sing_rs::CallObj
         })?,
     };
 
@@ -442,7 +442,7 @@ fn loop_inner(input: LoopParams, span: Span) -> Result<TokenStream2, Box<dyn Err
     // processing it by the match statements constructed above and write to output.
     Ok(quote! {
 		  use std::io::{BufRead, Write};
-		  use sing::TraitCallMessage;
+		  use sing_rs::TraitCallMessage;
 		  
         #( #initializations )*
 
